// This file is released under the 3-clause BSD license. See COPYING-BSD.

function hvtower(filename)
    // Import the .xls data into scilab using inpbar3d.sci
    [M,nod,elem,E,A,L,dircos,nn,ne] = inpbar3d(filename)
    
    // Implement the 3D linear bar element formulation using stiffbar3d.sci
    [kL,B,T,kG] = stiffbar3d(E,A,L,dircos,ne)
    
    // Assemble the stiffness matrix of the structure using assemb3d.sci
    //    Note: Depending on the element formulation, DOFn and DOFe might
    //    change. For the 3D linear bar element, there are 3 DOFs per node
    //    in the global coordinate system and thus 6 DOFs per element in the
    //    global coordinate system, since the element contains 2 nodes.
    [tc,K0] = assemb3d(elem,3,6,kG,nn,ne)
    
    // Plot the structure in the undeformed position using preplottruss3d.sci
    preplottruss3d(nod,elem,nn,ne,2)

    // Apply boundary conditions to the problem using bc.sci
    [K,P,cDOF,cDOFasc] = bc(M,K0);
    
    // Solve the matrix equations system using SPDsolve.sci. First, in SPDsolve
    // Verify the stiffness matrix is not singular using SPDverif.sci
    [u0,u,P0] = SPDsolve(K0,K,P,cDOF,cDOFasc,nn);
    
    // Compute the stresses on each bar using stressbar3d.sci
    [ue,sigma,f] = stressbar3d(E,A,B,T,tc,u0,ne);
    disp(sigma,"sigma =")
    
    // Plot the structure in the deformed position using postplottruss3d.sci
    //    Note: This function is intended to plot the structure on top of the
    //    previous plot. For this reason the nodes and element numbering are
    //    not recalled again, in the case that the 1st graphic was closed before.
    postplottruss3d(nod,elem,nn,ne,2,sigma,u0,100,24)
    
endfunction

lines(0);
f = scf();
f.figure_size = [550, 650];
Path = get_absolute_file_path("HVtower.dem.sce");
hvtower(Path + '/example_hvtower.xls');
demo_viewCode(Path+"/HVtower.dem.sce");   // sets the "View code" button
a = gca();
a.rotation_angles = [80,65];
clear f a hvtower Path;
