function SPDverif(K0,cDOFasc,K)
//Symmetric Positive Definite Stiffness Matrix Verificator
//Calling Sequence
// SPDverif(K0, cDOFasc, K)
//
//Parameters
// INPUT ARGUMENTS:
// K0: Complete stiffness matrix of the structure [DOFn*nn x DOFn*nn]     
// K: Active stiffness matrix of the structure (reduced to active DOF) [DOFn*nn-cDOF x DOFn*nn-cDOF]
// cDOFasc: Constrained degrees of freedom vector (ascending order) [cDOF x 1]
//
// See also
// assemb3d
// bc
// inpbar3d
// preplottruss3d
// postplottruss3d
// SPDsolve
// stiffbar3d
// stressbar3d
//
// Authors
// SPDVERIF Subroutine part of MABS3D
// (c)2010, Marcos C. Ruggeri
// mruggeri@frh.utn.edu.ar
// Universidad Tecnologica Nacional
// Facultad Regional Haedo
// Departamento Aeronautica

  // SPDVERIF Symmetric Positive Definite Stiffness Matrix Verificator
  //
  // =========================================================================
  // SYNTAX: SPDverif(K0,cDOFasc,K)
  // =========================================================================
  //
  // SPDVERIF Subroutine part of MABS3D
  // (c)2010, Marcos C. Ruggeri
  // mruggeri@frh.utn.edu.ar
  // Universidad Tecnologica Nacional
  // Facultad Regional Haedo
  // Departamento Aeronautica
  //
  //   Copyright 2010 Marcos C. Ruggeri
  //   $Revision: //REV 1.7 2010/08/08
  
  // MCR: REV:1.1.7 2010/11/26 for CEMEF-UTN v1.1-6
  
  //REV 1.6 2010/06/31------------START SPD VERIFICATION----------------------
  lines0_K0=zeroslines(K0);
  for i=1:max(size(lines0_K0))
    flag=0;
    for h=1:max(size(cDOFasc))
      if lines0_K0(i)==cDOFasc(h)
        flag=1;
        break
      else
      end
    end
    if flag==0 //Unconstrained DOF lin0_K0 not was removed by cDOF
      //Detecting possibility of corresponding unconstrained node to
      //uncDOF.
      uncDOF=lines0_K0(i);
      npos1=(uncDOF+2)/3; //x-direction
      npos2=(uncDOF+1)/3; //y-direction
      npos3=uncDOF/3; //z-direction
      if npos1==fix(npos1)
        uncn=npos1;
        comp=1; //DOF-component
      elseif npos2==fix(npos2)
        uncn=npos2;
        comp=2;
      else
        uncn=npos3;
        comp=3;
      end      
      warning(['RIGID BODY MOTION IN DOF-COMPONENT ',string(comp),' (DOF:',string(uncDOF),') FROM NODE ',string(uncn),' IS NOT PREVENTED.'])
    else
    end
  end
  if det(K)==0
    error('ACTIVE STIFFNESS MATRIX OF STRUCTURE IS SINGULAR. CHECK BOUNDARY CONDITIONS.')
  else
    disp('ACTIVE STIFFNESS MATRIX OF STRUCTURE IS NOT SINGULAR. SPD VERIFICATION COMPLETED SUCCESSFULLY.')
    // MCR: REV:1.1.7 2010/11/21 for CEMEF-UTN v1.1-5
  end
endfunction
//REV 1.6 2010/06/31------------END SPD VERIFICATION------------------------
function lines0=zeroslines(K0)
  lines0=[]; 
  cont=0;
  for j=1:max(size(K0)) //LBD: Command "length" in Scilab is not the same than
    //in MATLAB.
    if K0(:,j)==0
      cont=cont+1;
      lines0(cont)=j;
    else
    end
  end
endfunction
//Translated by LBD 2010/11/09





