function [K,P,cDOF,cDOFasc] = bc(M,K0)
// Importation of boundary conditions and reduction of system
//
//Calling Sequence
// [K, P, cDOF, cDOFasc] = bc(M, K0)
//
//Parameters
// INPUT ARGUMENTS:
// M: Data importation matrix (structured) //REV 1.1.3
// K0: Complete stiffness matrix of the structure [DOFn*nn x DOFn*nn]
// 
// :OUTPUT ARGUMENTS
// K: Active stiffness matrix of the structure (reduced to active DOF) [DOFn*nn-cDOF x DOFn*nn-cDOF]
// P: Nodal external loads vector (reduced to active DOF) [DOFn*nn-cDOF x 1]
// cDOF: Constrained degrees of freedom vector (descending order)  [cDOF x 1]
// cDOFasc: Constrained degrees of freedom vector (ascending order) [cDOF x 1]
//
// See also
// assemb3d
// inpbar3d
// preplottruss3d
// postplottruss3d
// SPDsolve
// SPDverif
// stiffbar3d
// stressbar3d
//
// Authors
// CEMEF-UTN v1.1-6
// Grupo de Simulacion y Mecanica Computacional
// Universidad Tecnologica Nacional
// Facultad Regional Haedo
//
//   Copyright 2010 UTN FRH GSMC
//   $Revision: //REV 1.1.6 2010/11/26 by MCR

  // ------------------------------------------------------------------------
  // BC ---> IMPORTATION OF BOUNDARY CONDITIONS AND REDUCTION OF SYSTEM
  //
  // SYNTAX:
  // [K,P,cDOF,cDOFasc]=bc(M,K0)
  // - Type: Function
  //
  // INPUT ARGUMENTS:
  // - M: Data importation matrix (structured) //REV 1.1.3
  // - K0: Complete stiffness matrix of the structure [DOFn*nn x DOFn*nn]
  // 
  // OUTPUT ARGUMENTS:
  // - K: Active stiffness matrix of the structure (reduced to active DOF) 
  //       [DOFn*nn-cDOF x DOFn*nn-cDOF]
  // - P: Nodal external loads vector (reduced to active DOF) 
  //       [DOFn*nn-cDOF x 1]
  // - cDOF: Constrained degrees of freedom vector (descending order) 
  //          [cDOF x 1]
  // - cDOFasc: Constrained degrees of freedom vector (ascending order)
  //             [cDOF x 1]
  //
  // CEMEF-UTN v1.1-6
  // Grupo de Simulacion y Mecanica Computacional
  // Universidad Tecnologica Nacional
  // Facultad Regional Haedo
  //
  //   Copyright 2010 UTN FRH GSMC
  //   $Revision: //REV 1.1.6 2010/11/26 by MCR
  
  // =========================================================================
  // BOUNDARY CONDITIONS: Data importation
  // =========================================================================
  external_loads=M(3);
  P=external_loads(3:2+3*nn,4); //REV 1.1.6 MCR: BUG FIXED
  boundary_conditions=M(4);
  cDOF=boundary_conditions(4:3+3*nn,3); //REV 1.1.6 MCR: BUG FIXED
  i=1;
  //REV 1.3 2010/04/27
  while i<=max(size(cDOF)) //special-purpose programmed low-level @for@ loop 
    if cDOF(i)==0
      cDOF(i,:)=[];
    else
      i=i+1;
    end
  end
  cDOFasc=cDOF; //REV 1.6 2010/06/31
  // Ordering cDOF vector (descending way)
  for i=1:max(size(cDOF))-1 
    for j=i+1:max(size(cDOF))
      if cDOF(i)<cDOF(j),
        aux=cDOF(i);
        cDOF(i)=cDOF(j);
        cDOF(j)=aux; 
      end
    end
  end
  // =========================================================================
  // Active stiffness matrix and nodal external loads vector of the structure
  // (reduced to active degrees of freedom dofs)
  // =========================================================================
  K=K0;
  // Reduction of the stiffness matrix and the nodal external loads vector to
  // active dofs
  for i=1:max(size(cDOF))
    K(cDOF(i),:)=[];
    K(:,cDOF(i))=[];
    P(cDOF(i))=[];
  end
endfunction
//Traslated by SDL 2010/10/08





