function postplottruss3d(nod,elem,nn,ne,kt,sigma,u0,amp,numcolors)
//Post-plot of three dimensional truss structure from CEMEF-UTN
//Calling Sequence
// postplottruss3d(nod, elem, nn, ne, kt, sigma, u0, amp, numcolors)
//
//Parameters
// INPUT ARGUMENTS:
// nod: Table of nodes [nn x 4]
// elem: Table of elements [ne x 9]
// nn: Number of nodes [1 x 1]
// ne: Number of elements [1 x 1]
// kt: Thickness amplification factor of truss lines [1 x 1]
// u0: Complete nodal displacements vector [DOFn*nn x 1]
// amp: Displacements amplification factor [1 x 1]
// numcolors: Quantity of color intervals for the colormap [1 x 1]
//
// Description
// Post-plot of three dimensional truss structure from CEMEF-UTN (contourplot
// of uni-dimensional normal stresses on each element of the structure)
//
// See also
// assemb3d
// bc
// inpbar3d
// preplottruss3d
// SPDsolve
// SPDverif
// stiffbar3d
// stressbar3d
//
// Authors
// CEMEF-UTN v1.1-6
//   Grupo de Simulacion y Mecanica Computacional
//   Universidad Tecnologica Nacional, Facultad Regional Haedo
//   Copyright 2010 UTN FRH GSMC
//   $Revision: //REV 1.1.1 2010/11/26 by MCR


  // POSTPLOTTRUSS3D ---> POST-PLOT OF THREE DIMENSIONAL TRUSS STRUCTURE FROM
  // CEMEF-UTN (CONTOURPLOT OF UNI-DIMENSIONAL NORMAL STRESSES ON EACH
  // ELEMENT OF THE STRUCTURE)
  //
  // SYNTAX:
  // postplottruss3d(nod,elem,nn,ne,kt,sigma,u0,amp,numcolors)
  // - Type: Function
  //
  // INPUT ARGUMENTS:
  // - nod: Table of nodes [nn x 4]
  // - elem: Table of elements [ne x 9]
  // - nn: Number of nodes [1 x 1]
  // - ne: Number of elements [1 x 1]
  // - kt: Thickness amplification factor of truss lines [1 x 1]
  // - u0: Complete nodal displacements vector [DOFn*nn x 1]
  // - amp: Displacements amplification factor [1 x 1]
  // - numcolors: Quantity of color intervals for the colormap [1 x 1]
  //
  // OUTPUT ARGUMENTS:
  //
  // CEMEF-UTN v1.1-6
  // Grupo de Simulacion y Mecanica Computacional
  // Universidad Tecnologica Nacional
  // Facultad Regional Haedo
  //
  //   Copyright 2010 UTN FRH GSMC
  //   $Revision: //REV 1.1.1 2010/11/26 by MCR
  
  // =========================================================================
  // POST-PROCESSING PLOT
  // =========================================================================
  drawlater()
  // Preallocation for speed and optimization porpuses
  xn = nod(:,2)
  yn = nod(:,3)
  zn = nod(:,4)
  xndef = zeros(nn,1)
  yndef = zeros(nn,1)
  zndef = zeros(nn,1)
  for i=1:nn
    xndef(i) = xn(i)+amp*u0(3*i-2)
    yndef(i) = yn(i)+amp*u0(3*i-1)
    zndef(i) = zn(i)+amp*u0(3*i)
  end
  //caxis([min(sigma),max(sigma)]);
  //cm=colormap;
  //Create a colormap with 'numcolors' qty of colors.
  h = gcf()
  cm = jetcolormap(numcolors)
  h.color_map = cm
  //AV: Create the colorbar reference with the limit tensions.
  colorbar(min(sigma),max(sigma));
  //AV: Associate an index to each sigma from 1 to numcolors
  index = fix((sigma-min(sigma))/(max(sigma)-min(sigma))*(max(size(cm))-1))+1
  //AV: It uses this index for each element to search the color in the colormap.  
  for i=1:ne
    xeldef = [xndef(elem(i,2)); xndef(elem(i,3))]
    yeldef = [yndef(elem(i,2)); yndef(elem(i,3))]
    zeldef = [zndef(elem(i,2)); zndef(elem(i,3))]
    param3d1(xeldef,yeldef,list(zeldef,index(i)))
    A = elem(i,9)
    s = gce()
    s.thickness = max(1,floor(kt*sqrt(4*A/%pi)))
  end
  txt = '$\magnification{1200}\mbox{Stress Distribution }\sigma_{11}'+..
        '\mbox{ - Amplification factor: $';
  xtitle([txt, string(amp)])
  
  //Delete axis and their labels
  a = gca();    
  a.axes_visible    = "off"
  a.x_label.visible = "off"
  a.y_label.visible = "off"
  a.z_label.visible = "off"
  a.box = "off"
  drawnow()
endfunction
//Translated by AV 2010/11/25













