function preplottruss3d(nod,elem,nn,ne,kt) //Modified by MCR 2010/10/14
//Pre-plot of three dimensional truss structure from CEMEF-UTN
//Calling Sequence
// preplottruss3d(nod, elem, nn, ne, kt)
//
//Parameters
// INPUT ARGUMENTS:
// nod: Table of nodes [nn x 4]
// elem: Table of elements [ne x 9]
// nn: Number of nodes [1 x 1]
// ne: Number of elements [1 x 1]
// kt: Thickness amplification factor of truss lines [1 x 1]
//
// See also
// assemb3d
// bc
// inpbar3d
// postplottruss3d
// SPDsolve
// SPDverif
// stiffbar3d
// stressbar3d
//
// Authors
// CEMEF-UTN v1.1-6; Grupo de Simulacion y Mecanica Computacional, Universidad Tecnologica Nacional, Facultad Regional Haedo
//   Copyright 2010 UTN FRH GSMC
//   $Revision: //REV 1.1.1 2010/11/26 by MCR

  // PREPLOTTRUSS3D ---> PRE-PLOT OF THREE DIMENSIONAL TRUSS STRUCTURE FROM
  // CEMEF-UTN
  //
  // SYNTAX: 
  // preplottruss3d(nod,elem,nn,ne,kt)
  // - Type: Function
  //
  // INPUT ARGUMENTS:
  // - nod: Table of nodes [nn x 4]
  // - elem: Table of elements [ne x 9]
  // - nn: Number of nodes [1 x 1]
  // - ne: Number of elements [1 x 1]
  // - kt: Thickness amplification factor of truss lines [1 x 1]
  //
  // OUTPUT ARGUMENTS:
  //
  // CEMEF-UTN v1.1-6
  // Grupo de Simulacion y Mecanica Computacional
  // Universidad Tecnologica Nacional
  // Facultad Regional Haedo
  //
  //   Copyright 2010 UTN FRH GSMC
  //   $Revision: //REV 1.1.5 2011/06/18 by MCR/AV
  
  // =========================================================================
  // PLOT
  // =========================================================================
  xn = nod(:,2)
  yn = nod(:,3)
  zn = nod(:,4)
  Dx = 0.03*mean(elem(:,4))
  Dy = 0.03*mean(elem(:,4))
  Dz = 0.03*mean(elem(:,4))
  
  f = gcf();
  f.immediate_drawing = "off"  // to accelerate plotting
  //Elements
  for i=1:ne 
    xel = [xn(elem(i,2)); xn(elem(i,3))]
    yel = [yn(elem(i,2)); yn(elem(i,3))]
    zel = [zn(elem(i,2)); zn(elem(i,3))]
    param3d1(xel,yel,list(zel,1))
    A = elem(i,9)                   //2010/11/22 AV
    s = gce();                  //2010/11/22 AV
    s.thickness = kt*sqrt(4*A/%pi);  //2010/11/22 AV
    xstring(mean(xel)+Dx,mean(yel)+Dy,string(i))
    e = gce()
    e.data(3) = mean(zel)+Dz
  end
  //Nodes in red color
  red = color("red")
  for i=1:nn
    xstring(xn(i)+Dx,yn(i)+Dy,string(i))
    g = gce();  
    g.data(3)=zn(i)+Dz
    ll = gce()
    ll.font_foreground = red
  end
  // Delete axis and their labels
  a = gca();    
  a.axes_visible = "off"
  a.x_label.visible = "off"
  a.y_label.visible = "off"
  a.z_label.visible = "off"
  a.box = "off"
  f.immediate_drawing = "on";
  show_window()
endfunction
//Translated by AV 2010/10/13
